pub struct BankAccount {
pub bank_name: Option<EncString>,
pub name_on_account: Option<EncString>,
pub account_type: Option<EncString>,
pub account_number: Option<EncString>,
pub routing_number: Option<EncString>,
pub branch_number: Option<EncString>,
pub pin: Option<EncString>,
pub swift_code: Option<EncString>,
pub iban: Option<EncString>,
pub bank_contact_phone: Option<EncString>,
}Fields
bank_name: Option<EncString>name_on_account: Option<EncString>account_type: Option<EncString>account_number: Option<EncString>routing_number: Option<EncString>branch_number: Option<EncString>pin: Option<EncString>swift_code: Option<EncString>iban: Option<EncString>bank_contact_phone: Option<EncString>Trait Implementations
Sourceimpl CipherKind for BankAccount
impl CipherKind for BankAccount
Sourcefn decrypt_subtitle(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<String, CryptoError>
fn decrypt_subtitle( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<String, CryptoError>
Returns the item’s subtitle.
Sourcefn get_copyable_fields(&self, _: Option<&Cipher>) -> Vec<CopyableCipherFields>
fn get_copyable_fields(&self, _: Option<&Cipher>) -> Vec<CopyableCipherFields>
Returns a list of populated fields for the cipher.
Sourceimpl Clone for BankAccount
impl Clone for BankAccount
Sourcefn clone(&self) -> BankAccount
fn clone(&self) -> BankAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, BankAccount> for BankAccountView
impl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, BankAccount> for BankAccountView
Sourcefn encrypt_composite(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<BankAccount, CryptoError>
fn encrypt_composite( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<BankAccount, CryptoError>
⚠️ IMPORTANT NOTE ⚠️ Read more
Sourceimpl<UT> ConvertError<UT> for BankAccount
impl<UT> ConvertError<UT> for BankAccount
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for BankAccount
impl Debug for BankAccount
Sourceimpl Decryptable<KeySlotIds, SymmetricKeySlotId, BankAccountView> for BankAccount
impl Decryptable<KeySlotIds, SymmetricKeySlotId, BankAccountView> for BankAccount
fn decrypt( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<BankAccountView, CryptoError>
Sourceimpl<'de> Deserialize<'de> for BankAccount
impl<'de> Deserialize<'de> for BankAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for BankAccount
impl<UT> FfiConverter<UT> for BankAccount
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<BankAccount> for CipherBankAccountModel
impl From<BankAccount> for CipherBankAccountModel
Sourcefn from(bank_account: BankAccount) -> Self
fn from(bank_account: BankAccount) -> Self
Converts to this type from the input type.
Sourceimpl From<BankAccount> for JsValuewhere
BankAccount: Serialize,
impl From<BankAccount> for JsValuewhere
BankAccount: Serialize,
Sourcefn from(value: BankAccount) -> Self
fn from(value: BankAccount) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
impl FromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &BankAccountwhere
BankAccount: Serialize,
impl IntoWasmAbi for &BankAccountwhere
BankAccount: Serialize,
Sourceimpl IntoWasmAbi for BankAccountwhere
BankAccount: Serialize,
impl IntoWasmAbi for BankAccountwhere
BankAccount: Serialize,
Sourceimpl<UT> Lift<UT> for BankAccount
impl<UT> Lift<UT> for BankAccount
Sourceimpl<UT> LiftRef<UT> for BankAccount
impl<UT> LiftRef<UT> for BankAccount
type LiftType = BankAccount
Sourceimpl<UT> LiftReturn<UT> for BankAccount
impl<UT> LiftReturn<UT> for BankAccount
Sourcetype ReturnType = <BankAccount as Lift<UT>>::FfiType
type ReturnType = <BankAccount as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for BankAccount
impl<UT> Lower<UT> for BankAccount
Sourceimpl<UT> LowerError<UT> for BankAccount
impl<UT> LowerError<UT> for BankAccount
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for BankAccount
impl<UT> LowerReturn<UT> for BankAccount
Sourcetype ReturnType = <BankAccount as Lower<UT>>::FfiType
type ReturnType = <BankAccount as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for BankAccountwhere
BankAccount: Serialize,
impl OptionIntoWasmAbi for BankAccountwhere
BankAccount: Serialize,
Sourceimpl RefFromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<BankAccount>
type Anchor = SelfOwner<BankAccount>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for BankAccount
impl Serialize for BankAccount
Sourceimpl TryFrom<CipherBankAccountModel> for BankAccount
impl TryFrom<CipherBankAccountModel> for BankAccount
Sourceimpl Tsify for BankAccount
impl Tsify for BankAccount
const DECL: &'static str = "export interface BankAccount {\n bankName: EncString | undefined;\n nameOnAccount: EncString | undefined;\n accountType: EncString | undefined;\n accountNumber: EncString | undefined;\n routingNumber: EncString | undefined;\n branchNumber: EncString | undefined;\n pin: EncString | undefined;\n swiftCode: EncString | undefined;\n iban: EncString | undefined;\n bankContactPhone: EncString | undefined;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for BankAccount
impl<UT> TypeId<UT> for BankAccount
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for BankAccountwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for BankAccountwhere
BankAccount: Serialize,
impl VectorIntoWasmAbi for BankAccountwhere
BankAccount: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for BankAccount
impl WasmDescribe for BankAccount
Sourceimpl WasmDescribeVector for BankAccount
impl WasmDescribeVector for BankAccount